Function rustc::middle::ty::has_attrUnstable
[-] [+]
[src]
pub fn has_attr(tcx: &ctxt, did: DefId, attr: &str) -> bool
Determine whether an item is annotated with an attribute
pub fn has_attr(tcx: &ctxt, did: DefId, attr: &str) -> bool
Determine whether an item is annotated with an attribute
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).